import { Construct } from "constructs";
/**
 * The `Secret` construct is a higher level CDK construct that makes it easy to manage app secrets.
 *
 * @example
 * ### Using the minimal config
 *
 * ```js
 * import { Config } from "@serverless-stack/resources";
 *
 * new Config.Secret(stack, "STRIPE_KEY");
 * ```
 */
export declare class Secret extends Construct {
    readonly name: string;
    private static all;
    constructor(scope: Construct, id: string);
    static getAllNames(): string[];
    static hasName(name: string): boolean;
    static clear(): Set<string>;
    getConstructMetadata(): {
        type: "Secret";
        data: {
            name: string;
        };
    };
}
